@@ -1,13 +1,13 @@
-const Liftoff = require('../..');
+var Liftoff = require('../..');
 
-const Test = new Liftoff({
+var Test = new Liftoff({
   name: 'test',
   v8flags: ['--lazy']
 });
-Test.on('respawn', function (proc) {
+Test.on('respawn', function(flags, proc) {
   console.log('saw respawn');
 });
 
-Test.launch({}, function (env) {
+Test.launch({}, function(env) {
   console.error(process.execArgv.join(''));
 });
